import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    list: {},
    detail: {
      status: 1,
      isSales: 1,
    },
    identityDict: [
      {
        label: '迎宾保安',
        value: 'first-usher',
      },
      {
        label: '迎宾前台',
        value: 'main-usher',
      },
      {
        label: '置业顾问',
        value: 'consultant',
      },
      {
        label: '其他',
        value: '',
      },
    ],
  },
  mutations: {
    updateList (state, payload) {
      state.list = payload || {}
    },
    updateDetail (state, payload) {
      state.detail = payload || { status: 1, isSales: 1 }
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', { isSales: 1, status: 1 })
    },
    getSysUserList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'sysuser.list')
        interact(api, payload).then((data) => {
          resolve(data)
          commit('updateList', data)
        }).catch(() => {
          reject()
        })
      })
    },
    getDetail ({ commit }, payload) {
      const api = replaceApiParams(lodash.get(apis, 'sysuser.detail'), payload)
      return interact(api).then((data) => {
        commit('updateDetail', data)
      })
    },
    addSysUser ( _, payload) {
      const dtStr = window.JSON.stringify(payload)
      const api = lodash.get(apis, 'sysuser.add')
      return interact(api, dtStr)
    },
    editSysUser ( _, payload) {
      const dtStr = window.JSON.stringify(payload)
      const api = lodash.get(apis, 'sysuser.edit')
      return interact(api, dtStr)
    },
    // deleteSysUser ( _, payload) {
    //   return new Promise((resolve, reject) => {
    //     const api = replaceApiParams(lodash.get(apis, 'sysuser.delete'), payload)
    //     interact(api).then((data) => {
    //       resolve(data)
    //     }).catch(() => {
    //       reject()
    //     })
    //   })
    // }
  }
}
